##  Set Up Single Sign-On (SSO)
To streamline user and access management for your organization, set up SSO. With SSO, users sign in to SAP LeanIX through your organization’s identity provider (IdP) system, which ensures secure access. Work with your IT administrators to define the SSO setup that suits your organization.
You can manage authorization (user roles) in SAP LeanIX or through your IdP. When setting up SSO, choose how you want to manage authorization.
Optionally, you can set up System for Cross-Domain Identity Management (SCIM) to automatically sync user states from your IdP, which streamlines user provisioning, deprovisioning, and updating.
For detailed information, refer to:
  * [Single Sign-On (SSO)](https://help.sap.com/docs/leanix/ea/single-sign-on-sso?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to configure single sign-on \(SSO\) with SAP LeanIX.")
  * [SCIM Provisioning](https://help.sap.com/docs/leanix/ea/scim-provisioning?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to configure System for Cross-Domain Identity Management \(SCIM\) for seamless user state synchronization.")
